Changelog
=========

1.2 - Unreleased
----------------
* Key class now accepts PEM formated keys [Russell]
* Python 2.6 compatability, removed dependency on xpath [Russell]
* Now using nose testing [Russell]


1.1 - (2009-10-29)
------------------
* updated documentation, including addition of sphinx [Russell]
* Jython hack added to support webstart [Markus]
* Jython example code added [Markus]
* added slcs support functions [Russell]
* Centos ignores M2Crypto requirement [Russell]
* New certificates now have a start time of -5min [Sam]
* Updated proxy name generation to avoid encoding errors [Russell]


1.0 (2009-07-08)
----------------

* Initial release
* Certificate Classes added
* Proxy Classes added
* Key Classes added

